/* AdjustDateTimeDialog.c generated by valac 0.36.6, the Vala compiler
 * generated from AdjustDateTimeDialog.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 * Copyright 2017 Jens Georg <mail@jensge.org>
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <time.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <gdk-pixbuf/gdk-pixbuf.h>


#define TYPE_ADJUST_DATE_TIME_DIALOG (adjust_date_time_dialog_get_type ())
#define ADJUST_DATE_TIME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialog))
#define ADJUST_DATE_TIME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialogClass))
#define IS_ADJUST_DATE_TIME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADJUST_DATE_TIME_DIALOG))
#define IS_ADJUST_DATE_TIME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ADJUST_DATE_TIME_DIALOG))
#define ADJUST_DATE_TIME_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialogClass))

typedef struct _AdjustDateTimeDialog AdjustDateTimeDialog;
typedef struct _AdjustDateTimeDialogClass AdjustDateTimeDialogClass;
typedef struct _AdjustDateTimeDialogPrivate AdjustDateTimeDialogPrivate;

#define ADJUST_DATE_TIME_DIALOG_TYPE_TIME_SYSTEM (adjust_date_time_dialog_time_system_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_DATEABLE (dateable_get_type ())
#define DATEABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATEABLE, Dateable))
#define IS_DATEABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATEABLE))
#define DATEABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_DATEABLE, DateableIface))

typedef struct _Dateable Dateable;
typedef struct _DateableIface DateableIface;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AdjustDateTimeDialog {
	GtkDialog parent_instance;
	AdjustDateTimeDialogPrivate * priv;
};

struct _AdjustDateTimeDialogClass {
	GtkDialogClass parent_class;
};

typedef enum  {
	ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM,
	ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM,
	ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR
} AdjustDateTimeDialogTimeSystem;

struct _AdjustDateTimeDialogPrivate {
	gboolean no_original_time;
	time_t original_time;
	GtkLabel* original_time_label;
	GtkCalendar* calendar;
	GtkSpinButton* hour;
	GtkSpinButton* minute;
	GtkSpinButton* second;
	GtkComboBoxText* system;
	GtkRadioButton* relativity_radio_button;
	GtkRadioButton* batch_radio_button;
	GtkCheckButton* modify_originals_check_button;
	GtkLabel* notification;
	AdjustDateTimeDialogTimeSystem previous_time_system;
};

struct _DateableIface {
	GTypeInterface parent_iface;
	void (*set_exposure_time) (Dateable* self, time_t target_time);
	time_t (*get_exposure_time) (Dateable* self);
};


static gpointer adjust_date_time_dialog_parent_class = NULL;

GType adjust_date_time_dialog_get_type (void) G_GNUC_CONST;
static GType adjust_date_time_dialog_time_system_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define ADJUST_DATE_TIME_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialogPrivate))
enum  {
	ADJUST_DATE_TIME_DIALOG_DUMMY_PROPERTY
};
#define ADJUST_DATE_TIME_DIALOG_SECONDS_IN_DAY ((gint64) ((60 * 60) * 24))
#define ADJUST_DATE_TIME_DIALOG_SECONDS_IN_HOUR ((gint64) (60 * 60))
#define ADJUST_DATE_TIME_DIALOG_SECONDS_IN_MINUTE ((gint64) 60)
#define ADJUST_DATE_TIME_DIALOG_YEAR_OFFSET 1900
#define ADJUST_DATE_TIME_DIALOG_CALENDAR_THUMBNAIL_SCALE 1
GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType dateable_get_type (void) G_GNUC_CONST;
AdjustDateTimeDialog* adjust_date_time_dialog_new (Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video);
AdjustDateTimeDialog* adjust_date_time_dialog_construct (GType object_type, Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video);
gint resources_use_header_bar (void);
GType page_window_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
AppWindow* app_window_get_instance (void);
#define RESOURCES_CANCEL_LABEL _ ("_Cancel")
#define RESOURCES_OK_LABEL _ ("_OK")
#define RESOURCES_ADJUST_DATE_TIME_LABEL _ ("Adjust Date and Time")
static void adjust_date_time_dialog_on_time_changed (AdjustDateTimeDialog* self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_day_selected (GtkCalendar* _sender, gpointer self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_month_changed (GtkCalendar* _sender, gpointer self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_next_year (GtkCalendar* _sender, gpointer self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_prev_year (GtkCalendar* _sender, gpointer self);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
gboolean configuration_facade_get_use_24_hour_time (ConfigurationFacade* self);
static gboolean adjust_date_time_dialog_on_spin_button_output (AdjustDateTimeDialog* self, GtkSpinButton* button);
static gboolean _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output (GtkSpinButton* _sender, gpointer self);
static void adjust_date_time_dialog_on_time_system_changed (AdjustDateTimeDialog* self);
static void _adjust_date_time_dialog_on_time_system_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
gboolean configuration_facade_get_keep_relativity (ConfigurationFacade* self);
static void _adjust_date_time_dialog_on_time_changed_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self);
gboolean configuration_facade_get_commit_metadata_to_masters (ConfigurationFacade* self);
GdkPixbuf* thumbnail_source_get_thumbnail (ThumbnailSource* self, gint scale, GError** error);
gchar* data_object_to_string (DataObject* self);
time_t dateable_get_exposure_time (Dateable* self);
static void adjust_date_time_dialog_set_time (AdjustDateTimeDialog* self, struct tm* time);
static void adjust_date_time_dialog_set_original_time_label (AdjustDateTimeDialog* self, gboolean use_24_hr_format);
static time_t adjust_date_time_dialog_get_time (AdjustDateTimeDialog* self);
gboolean adjust_date_time_dialog_execute (AdjustDateTimeDialog* self, gint64* time_shift, gboolean* keep_relativity, gboolean* modify_originals);
void configuration_facade_set_keep_relativity (ConfigurationFacade* self, gboolean keep_relativity);
void configuration_facade_set_modify_originals (ConfigurationFacade* self, gboolean modify_originals);
void configuration_facade_set_use_24_hour_time (ConfigurationFacade* self, gboolean use_24_hour_time);
static void adjust_date_time_dialog_finalize (GObject * obj);


static GType adjust_date_time_dialog_time_system_get_type (void) {
	static volatile gsize adjust_date_time_dialog_time_system_type_id__volatile = 0;
	if (g_once_init_enter (&adjust_date_time_dialog_time_system_type_id__volatile)) {
		static const GEnumValue values[] = {{ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM, "ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM", "am"}, {ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM, "ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM", "pm"}, {ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR, "ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR", "24hr"}, {0, NULL, NULL}};
		GType adjust_date_time_dialog_time_system_type_id;
		adjust_date_time_dialog_time_system_type_id = g_enum_register_static ("AdjustDateTimeDialogTimeSystem", values);
		g_once_init_leave (&adjust_date_time_dialog_time_system_type_id__volatile, adjust_date_time_dialog_time_system_type_id);
	}
	return adjust_date_time_dialog_time_system_type_id__volatile;
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_day_selected (GtkCalendar* _sender, gpointer self) {
#line 53 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 241 "AdjustDateTimeDialog.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_month_changed (GtkCalendar* _sender, gpointer self) {
#line 54 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 248 "AdjustDateTimeDialog.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_next_year (GtkCalendar* _sender, gpointer self) {
#line 55 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 255 "AdjustDateTimeDialog.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_prev_year (GtkCalendar* _sender, gpointer self) {
#line 56 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 262 "AdjustDateTimeDialog.c"
}


static gboolean _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output (GtkSpinButton* _sender, gpointer self) {
	gboolean result;
	result = adjust_date_time_dialog_on_spin_button_output ((AdjustDateTimeDialog*) self, _sender);
#line 63 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	return result;
#line 271 "AdjustDateTimeDialog.c"
}


static void _adjust_date_time_dialog_on_time_system_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 81 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	adjust_date_time_dialog_on_time_system_changed ((AdjustDateTimeDialog*) self);
#line 278 "AdjustDateTimeDialog.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self) {
#line 103 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 285 "AdjustDateTimeDialog.c"
}


static void g_time_gm (time_t time, struct tm* result) {
	struct tm _result_ = {0};
	struct tm _tmp0_ = {0};
#line 2841 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	gmtime_r (&time, &_tmp0_);
#line 2841 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 2842 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	*result = _result_;
#line 2842 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return;
#line 300 "AdjustDateTimeDialog.c"
}


static gchar* g_time_format (struct tm *self, const gchar* format) {
	gchar* result = NULL;
	gchar* buffer = NULL;
	gchar* _tmp0_;
	gint buffer_length1;
	gint _buffer_size_;
	gchar* _tmp1_;
	gint _tmp1__length1;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gint _tmp3__length1;
	gchar* _tmp4_;
#line 2854 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (format != NULL, NULL);
#line 2855 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = g_new0 (gchar, 64);
#line 2855 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	buffer = _tmp0_;
#line 2855 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	buffer_length1 = 64;
#line 2855 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_buffer_size_ = buffer_length1;
#line 2856 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = buffer;
#line 2856 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1__length1 = buffer_length1;
#line 2856 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp2_ = format;
#line 2856 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	strftime (_tmp1_, _tmp1__length1, _tmp2_, &(*self));
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = buffer;
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3__length1 = buffer_length1;
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4_ = g_strdup ((const gchar*) _tmp3_);
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	buffer = (g_free (buffer), NULL);
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 346 "AdjustDateTimeDialog.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	return self ? g_object_ref (self) : NULL;
#line 353 "AdjustDateTimeDialog.c"
}


static void g_time_local (time_t time, struct tm* result) {
	struct tm _result_ = {0};
	struct tm _tmp0_ = {0};
#line 2846 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	localtime_r (&time, &_tmp0_);
#line 2846 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 2847 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	*result = _result_;
#line 2847 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return;
#line 368 "AdjustDateTimeDialog.c"
}


AdjustDateTimeDialog* adjust_date_time_dialog_construct (GType object_type, Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video) {
	AdjustDateTimeDialog * self = NULL;
	Dateable* _tmp0_;
	gint _tmp1_;
	AppWindow* _tmp2_;
	AppWindow* _tmp3_;
	GtkCalendar* _tmp4_;
	GtkCalendar* _tmp5_;
	GtkCalendar* _tmp6_;
	GtkCalendar* _tmp7_;
	GtkCalendar* _tmp8_;
	GtkCalendar* _tmp9_;
	ConfigFacade* _tmp10_;
	ConfigFacade* _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_;
	GtkSpinButton* _tmp16_;
	GtkSpinButton* _tmp17_;
	GtkSpinButton* _tmp18_;
	GtkSpinButton* _tmp19_;
	GtkSpinButton* _tmp20_;
	GtkSpinButton* _tmp21_;
	GtkSpinButton* _tmp22_;
	GtkSpinButton* _tmp23_;
	GtkSpinButton* _tmp24_;
	GtkSpinButton* _tmp25_;
	GtkSpinButton* _tmp26_;
	GtkComboBoxText* _tmp27_;
	GtkComboBoxText* _tmp28_;
	GtkComboBoxText* _tmp29_;
	GtkComboBoxText* _tmp30_;
	GtkComboBoxText* _tmp31_;
	GtkBox* clock = NULL;
	GtkBox* _tmp32_;
	GtkBox* _tmp33_;
	GtkSpinButton* _tmp34_;
	GtkBox* _tmp35_;
	GtkLabel* _tmp36_;
	GtkLabel* _tmp37_;
	GtkBox* _tmp38_;
	GtkSpinButton* _tmp39_;
	GtkBox* _tmp40_;
	GtkLabel* _tmp41_;
	GtkLabel* _tmp42_;
	GtkBox* _tmp43_;
	GtkSpinButton* _tmp44_;
	GtkBox* _tmp45_;
	GtkComboBoxText* _tmp46_;
	GtkRadioButton* _tmp47_;
	GtkRadioButton* _tmp48_;
	ConfigFacade* _tmp49_;
	ConfigFacade* _tmp50_;
	gboolean _tmp51_;
	gboolean _tmp52_ = FALSE;
	gboolean _tmp53_;
	GtkRadioButton* _tmp55_;
	GtkRadioButton* _tmp56_;
	GSList* _tmp57_;
	GtkRadioButton* _tmp58_;
	GtkRadioButton* _tmp59_;
	ConfigFacade* _tmp60_;
	ConfigFacade* _tmp61_;
	gboolean _tmp62_;
	gboolean _tmp63_ = FALSE;
	gboolean _tmp64_;
	GtkRadioButton* _tmp66_;
	GtkRadioButton* _tmp67_;
	gboolean _tmp68_;
	gboolean _tmp77_ = FALSE;
	ConfigFacade* _tmp78_;
	ConfigFacade* _tmp79_;
	gboolean _tmp80_;
	gboolean _tmp81_;
	GtkCheckButton* _tmp83_;
	gboolean _tmp84_ = FALSE;
	gboolean _tmp85_;
	GtkCheckButton* _tmp92_;
	GtkBox* time_content = NULL;
	GtkBox* _tmp93_;
	GtkBox* picker = NULL;
	GtkBox* _tmp94_;
	GtkComboBoxText* combo = NULL;
	GtkComboBoxText* _tmp95_;
	GtkBox* _tmp104_;
	GtkComboBoxText* _tmp105_;
	GtkSpinButton* spin = NULL;
	GtkSpinButton* _tmp106_;
	GtkBox* _tmp107_;
	GtkSpinButton* _tmp108_;
	GtkSpinButton* _tmp109_;
	GtkCalendar* _tmp110_;
	GtkComboBoxText* _tmp111_;
	GtkCalendar* _tmp112_;
	GtkBox* _tmp113_;
	GtkBox* _tmp114_;
	GtkBox* _tmp115_;
	GtkCalendar* _tmp116_;
	GtkBox* _tmp117_;
	GtkBox* _tmp118_;
	gboolean _tmp119_;
	GdkPixbuf* preview = NULL;
	GtkBox* image_content = NULL;
	GtkBox* _tmp133_;
	GtkBox* _tmp134_;
	GtkBox* _tmp135_;
	GtkImage* _tmp136_ = NULL;
	GdkPixbuf* _tmp137_;
	GtkImage* image = NULL;
	GtkImage* _tmp141_;
	GtkLabel* _tmp142_;
	GtkBox* _tmp143_;
	GtkImage* _tmp144_;
	GtkBox* _tmp145_;
	GtkLabel* _tmp146_;
	GtkBox* hbox = NULL;
	GtkBox* _tmp147_;
	GtkBox* _tmp148_;
	GtkBox* _tmp149_;
	GtkBox* _tmp150_;
	GtkBox* _tmp151_;
	GtkBox* _tmp152_;
	GtkBox* _tmp153_;
	GtkBox* _tmp154_;
	GtkBox* _tmp155_;
	GtkBox* _tmp156_;
	GtkBox* _tmp157_;
	GtkBox* _tmp158_;
	GtkLabel* _tmp159_;
	GtkLabel* _tmp160_;
	GtkLabel* _tmp161_;
	GtkBox* _tmp162_;
	GtkLabel* _tmp163_;
	Dateable* _tmp164_;
	time_t _tmp165_;
	time_t _tmp166_;
	time_t _tmp168_;
	struct tm _tmp169_ = {0};
	ConfigFacade* _tmp170_;
	ConfigFacade* _tmp171_;
	gboolean _tmp172_;
	GError * _inner_error_ = NULL;
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_return_val_if_fail (IS_DATEABLE (source), NULL);
#line 39 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp0_ = source;
#line 39 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_vala_assert (_tmp0_ != NULL, "source != null");
#line 41 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp1_ = resources_use_header_bar ();
#line 41 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self = (AdjustDateTimeDialog*) g_object_new (object_type, "use-header-bar", _tmp1_, NULL);
#line 43 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_window_set_modal (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 44 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 45 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp2_ = app_window_get_instance ();
#line 45 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp3_ = _tmp2_;
#line 45 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_window_get_type (), GtkWindow));
#line 45 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (_tmp3_);
#line 47 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_OK_LABEL, GTK_RESPONSE_OK, NULL);
#line 49 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), RESOURCES_ADJUST_DATE_TIME_LABEL);
#line 51 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp4_ = (GtkCalendar*) gtk_calendar_new ();
#line 51 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp4_);
#line 51 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->calendar);
#line 51 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->calendar = _tmp4_;
#line 52 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp5_ = self->priv->calendar;
#line 52 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_set (_tmp5_, "show-heading", FALSE, NULL);
#line 53 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp6_ = self->priv->calendar;
#line 53 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_signal_connect_object (_tmp6_, "day-selected", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_day_selected, self, 0);
#line 54 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp7_ = self->priv->calendar;
#line 54 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_signal_connect_object (_tmp7_, "month-changed", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_month_changed, self, 0);
#line 55 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp8_ = self->priv->calendar;
#line 55 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_signal_connect_object (_tmp8_, "next-year", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_next_year, self, 0);
#line 56 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp9_ = self->priv->calendar;
#line 56 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_signal_connect_object (_tmp9_, "prev-year", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_prev_year, self, 0);
#line 58 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp10_ = config_facade_get_instance ();
#line 58 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp11_ = _tmp10_;
#line 58 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp12_ = configuration_facade_get_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 58 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp13_ = _tmp12_;
#line 58 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (_tmp11_);
#line 58 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp13_) {
#line 579 "AdjustDateTimeDialog.c"
		GtkSpinButton* _tmp14_;
#line 59 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp14_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 0, (gdouble) 23, (gdouble) 1);
#line 59 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		g_object_ref_sink (_tmp14_);
#line 59 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (self->priv->hour);
#line 59 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		self->priv->hour = _tmp14_;
#line 589 "AdjustDateTimeDialog.c"
	} else {
		GtkSpinButton* _tmp15_;
#line 61 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp15_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 1, (gdouble) 12, (gdouble) 1);
#line 61 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		g_object_ref_sink (_tmp15_);
#line 61 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (self->priv->hour);
#line 61 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		self->priv->hour = _tmp15_;
#line 600 "AdjustDateTimeDialog.c"
	}
#line 63 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp16_ = self->priv->hour;
#line 63 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_signal_connect_object (_tmp16_, "output", (GCallback) _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output, self, 0);
#line 64 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp17_ = self->priv->hour;
#line 64 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_entry_set_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_entry_get_type (), GtkEntry), 2);
#line 65 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp18_ = self->priv->hour;
#line 65 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_entry_set_max_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_entry_get_type (), GtkEntry), 2);
#line 67 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp19_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 0, (gdouble) 59, (gdouble) 1);
#line 67 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp19_);
#line 67 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->minute);
#line 67 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->minute = _tmp19_;
#line 68 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp20_ = self->priv->minute;
#line 68 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_entry_set_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_entry_get_type (), GtkEntry), 2);
#line 69 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp21_ = self->priv->minute;
#line 69 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_entry_set_max_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_entry_get_type (), GtkEntry), 2);
#line 70 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp22_ = self->priv->minute;
#line 70 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_signal_connect_object (_tmp22_, "output", (GCallback) _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output, self, 0);
#line 72 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp23_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 0, (gdouble) 59, (gdouble) 1);
#line 72 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp23_);
#line 72 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->second);
#line 72 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->second = _tmp23_;
#line 73 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp24_ = self->priv->second;
#line 73 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_entry_set_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_entry_get_type (), GtkEntry), 2);
#line 74 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp25_ = self->priv->second;
#line 74 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_entry_set_max_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_entry_get_type (), GtkEntry), 2);
#line 75 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp26_ = self->priv->second;
#line 75 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_signal_connect_object (_tmp26_, "output", (GCallback) _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output, self, 0);
#line 77 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp27_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 77 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp27_);
#line 77 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->system);
#line 77 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->system = _tmp27_;
#line 78 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp28_ = self->priv->system;
#line 78 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_combo_box_text_append_text (_tmp28_, _ ("AM"));
#line 79 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp29_ = self->priv->system;
#line 79 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_combo_box_text_append_text (_tmp29_, _ ("PM"));
#line 80 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp30_ = self->priv->system;
#line 80 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_combo_box_text_append_text (_tmp30_, _ ("24 Hr"));
#line 81 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp31_ = self->priv->system;
#line 81 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _adjust_date_time_dialog_on_time_system_changed_gtk_combo_box_changed, self, 0);
#line 83 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp32_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
#line 83 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp32_);
#line 83 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	clock = _tmp32_;
#line 85 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp33_ = clock;
#line 85 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp34_ = self->priv->hour;
#line 85 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp33_, G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 86 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp35_ = clock;
#line 86 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp36_ = (GtkLabel*) gtk_label_new (":");
#line 86 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp36_);
#line 86 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp37_ = _tmp36_;
#line 86 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp35_, G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 86 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (_tmp37_);
#line 87 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp38_ = clock;
#line 87 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp39_ = self->priv->minute;
#line 87 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp38_, G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 88 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp40_ = clock;
#line 88 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp41_ = (GtkLabel*) gtk_label_new (":");
#line 88 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp41_);
#line 88 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp42_ = _tmp41_;
#line 88 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp40_, G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 88 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (_tmp42_);
#line 89 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp43_ = clock;
#line 89 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp44_ = self->priv->second;
#line 89 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp43_, G_TYPE_CHECK_INSTANCE_CAST (_tmp44_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 90 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp45_ = clock;
#line 90 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp46_ = self->priv->system;
#line 90 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp45_, G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 92 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 94 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp47_ = (GtkRadioButton*) gtk_radio_button_new_with_mnemonic (NULL, _ ("_Shift photos/videos by the same amount"));
#line 94 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp47_);
#line 94 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->relativity_radio_button);
#line 94 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->relativity_radio_button = _tmp47_;
#line 96 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp48_ = self->priv->relativity_radio_button;
#line 96 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp49_ = config_facade_get_instance ();
#line 96 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp50_ = _tmp49_;
#line 96 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp51_ = configuration_facade_get_keep_relativity (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 96 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp51_);
#line 96 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (_tmp50_);
#line 97 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp53_ = display_options;
#line 97 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp53_) {
#line 758 "AdjustDateTimeDialog.c"
		gint _tmp54_;
#line 97 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp54_ = photo_count;
#line 97 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp52_ = _tmp54_ > 1;
#line 764 "AdjustDateTimeDialog.c"
	} else {
#line 97 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp52_ = FALSE;
#line 768 "AdjustDateTimeDialog.c"
	}
#line 97 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp55_ = self->priv->relativity_radio_button;
#line 97 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, gtk_widget_get_type (), GtkWidget), _tmp52_);
#line 99 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp56_ = self->priv->relativity_radio_button;
#line 99 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp57_ = gtk_radio_button_get_group (_tmp56_);
#line 99 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp58_ = (GtkRadioButton*) gtk_radio_button_new_with_mnemonic (_tmp57_, _ ("Set _all photos/videos to this time"));
#line 99 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp58_);
#line 99 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->batch_radio_button);
#line 99 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->batch_radio_button = _tmp58_;
#line 101 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp59_ = self->priv->batch_radio_button;
#line 101 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp60_ = config_facade_get_instance ();
#line 101 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp61_ = _tmp60_;
#line 101 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp62_ = configuration_facade_get_keep_relativity (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 101 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, gtk_toggle_button_get_type (), GtkToggleButton), !_tmp62_);
#line 101 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (_tmp61_);
#line 102 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp64_ = display_options;
#line 102 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp64_) {
#line 802 "AdjustDateTimeDialog.c"
		gint _tmp65_;
#line 102 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp65_ = photo_count;
#line 102 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp63_ = _tmp65_ > 1;
#line 808 "AdjustDateTimeDialog.c"
	} else {
#line 102 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp63_ = FALSE;
#line 812 "AdjustDateTimeDialog.c"
	}
#line 102 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp66_ = self->priv->batch_radio_button;
#line 102 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp66_, gtk_widget_get_type (), GtkWidget), _tmp63_);
#line 103 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp67_ = self->priv->batch_radio_button;
#line 103 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, gtk_toggle_button_get_type (), GtkToggleButton), "toggled", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_toggle_button_toggled, self, 0);
#line 105 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp68_ = contains_video;
#line 105 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp68_) {
#line 826 "AdjustDateTimeDialog.c"
		gchar* text = NULL;
		gint _tmp69_;
		gchar* _tmp70_;
		const gchar* _tmp71_;
		GtkCheckButton* _tmp72_;
#line 106 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp69_ = photo_count;
#line 106 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp70_ = g_strdup (ngettext ("_Modify original photo file", "_Modify original photo files", (gulong) _tmp69_));
#line 106 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		text = _tmp70_;
#line 108 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp71_ = text;
#line 108 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp72_ = (GtkCheckButton*) gtk_check_button_new_with_mnemonic (_tmp71_);
#line 108 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		g_object_ref_sink (_tmp72_);
#line 108 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (self->priv->modify_originals_check_button);
#line 108 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		self->priv->modify_originals_check_button = _tmp72_;
#line 105 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_free0 (text);
#line 850 "AdjustDateTimeDialog.c"
	} else {
		gchar* text = NULL;
		gint _tmp73_;
		gchar* _tmp74_;
		const gchar* _tmp75_;
		GtkCheckButton* _tmp76_;
#line 110 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp73_ = photo_count;
#line 110 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp74_ = g_strdup (ngettext ("_Modify original file", "_Modify original files", (gulong) _tmp73_));
#line 110 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		text = _tmp74_;
#line 111 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp75_ = text;
#line 111 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp76_ = (GtkCheckButton*) gtk_check_button_new_with_mnemonic (_tmp75_);
#line 111 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		g_object_ref_sink (_tmp76_);
#line 111 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (self->priv->modify_originals_check_button);
#line 111 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		self->priv->modify_originals_check_button = _tmp76_;
#line 105 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_free0 (text);
#line 875 "AdjustDateTimeDialog.c"
	}
#line 114 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp78_ = config_facade_get_instance ();
#line 114 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp79_ = _tmp78_;
#line 114 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp80_ = configuration_facade_get_commit_metadata_to_masters (G_TYPE_CHECK_INSTANCE_CAST (_tmp79_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 114 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp81_ = _tmp80_;
#line 114 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (_tmp79_);
#line 114 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp81_) {
#line 889 "AdjustDateTimeDialog.c"
		gboolean _tmp82_;
#line 115 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp82_ = display_options;
#line 115 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp77_ = _tmp82_;
#line 895 "AdjustDateTimeDialog.c"
	} else {
#line 114 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp77_ = FALSE;
#line 899 "AdjustDateTimeDialog.c"
	}
#line 114 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp83_ = self->priv->modify_originals_check_button;
#line 114 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp83_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp77_);
#line 116 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp85_ = only_video;
#line 116 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (!_tmp85_) {
#line 909 "AdjustDateTimeDialog.c"
		gboolean _tmp86_ = FALSE;
		ConfigFacade* _tmp87_;
		ConfigFacade* _tmp88_;
		gboolean _tmp89_;
		gboolean _tmp90_;
#line 117 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp87_ = config_facade_get_instance ();
#line 117 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp88_ = _tmp87_;
#line 117 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp89_ = configuration_facade_get_commit_metadata_to_masters (G_TYPE_CHECK_INSTANCE_CAST (_tmp88_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 117 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp90_ = !_tmp89_;
#line 117 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (_tmp88_);
#line 117 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (_tmp90_) {
#line 927 "AdjustDateTimeDialog.c"
			gboolean _tmp91_;
#line 117 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp91_ = display_options;
#line 117 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp86_ = _tmp91_;
#line 933 "AdjustDateTimeDialog.c"
		} else {
#line 117 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp86_ = FALSE;
#line 937 "AdjustDateTimeDialog.c"
		}
#line 117 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp84_ = _tmp86_;
#line 941 "AdjustDateTimeDialog.c"
	} else {
#line 116 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp84_ = FALSE;
#line 945 "AdjustDateTimeDialog.c"
	}
#line 116 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp92_ = self->priv->modify_originals_check_button;
#line 116 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp92_, gtk_widget_get_type (), GtkWidget), _tmp84_);
#line 119 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp93_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
#line 119 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp93_);
#line 119 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	time_content = _tmp93_;
#line 121 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp94_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
#line 121 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp94_);
#line 121 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	picker = _tmp94_;
#line 122 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp95_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 122 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp95_);
#line 122 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	combo = _tmp95_;
#line 969 "AdjustDateTimeDialog.c"
	{
		gint i = 0;
#line 123 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		i = 0;
#line 974 "AdjustDateTimeDialog.c"
		{
			gboolean _tmp96_ = FALSE;
#line 123 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp96_ = TRUE;
#line 123 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			while (TRUE) {
#line 981 "AdjustDateTimeDialog.c"
				gint _tmp98_;
				GtkComboBoxText* _tmp99_;
				gint _tmp100_;
				struct tm _tmp101_ = {0};
				gchar* _tmp102_;
				gchar* _tmp103_;
#line 123 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
				if (!_tmp96_) {
#line 990 "AdjustDateTimeDialog.c"
					gint _tmp97_;
#line 123 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
					_tmp97_ = i;
#line 123 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
					i = _tmp97_ + 1;
#line 996 "AdjustDateTimeDialog.c"
				}
#line 123 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
				_tmp96_ = FALSE;
#line 123 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
				_tmp98_ = i;
#line 123 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
				if (!(_tmp98_ < 12)) {
#line 123 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
					break;
#line 1006 "AdjustDateTimeDialog.c"
				}
#line 124 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
				_tmp99_ = combo;
#line 124 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
				_tmp100_ = i;
#line 124 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
				g_time_gm ((time_t) (_tmp100_ * 2764800), &_tmp101_);
#line 124 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
				_tmp102_ = g_time_format (&_tmp101_, "%B");
#line 124 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
				_tmp103_ = _tmp102_;
#line 124 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
				gtk_combo_box_text_append_text (_tmp99_, _tmp103_);
#line 124 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
				_g_free0 (_tmp103_);
#line 1022 "AdjustDateTimeDialog.c"
			}
		}
	}
#line 126 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp104_ = picker;
#line 126 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp105_ = combo;
#line 126 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp104_, G_TYPE_CHECK_INSTANCE_CAST (_tmp105_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 128 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp106_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 0, (gdouble) (G_MAXINT >> 9), (gdouble) 1);
#line 128 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp106_);
#line 128 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	spin = _tmp106_;
#line 129 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp107_ = picker;
#line 129 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp108_ = spin;
#line 129 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_end (_tmp107_, G_TYPE_CHECK_INSTANCE_CAST (_tmp108_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 130 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp109_ = spin;
#line 130 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp110_ = self->priv->calendar;
#line 130 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_bind_property_with_closures (G_TYPE_CHECK_INSTANCE_CAST (_tmp109_, G_TYPE_OBJECT, GObject), "value", G_TYPE_CHECK_INSTANCE_CAST (_tmp110_, G_TYPE_OBJECT, GObject), "year", G_BINDING_BIDIRECTIONAL, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 131 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp111_ = combo;
#line 131 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp112_ = self->priv->calendar;
#line 131 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_bind_property_with_closures (G_TYPE_CHECK_INSTANCE_CAST (_tmp111_, G_TYPE_OBJECT, GObject), "active", G_TYPE_CHECK_INSTANCE_CAST (_tmp112_, G_TYPE_OBJECT, GObject), "month", G_BINDING_BIDIRECTIONAL, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 133 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp113_ = time_content;
#line 133 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp114_ = picker;
#line 133 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp113_, G_TYPE_CHECK_INSTANCE_CAST (_tmp114_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 134 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp115_ = time_content;
#line 134 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp116_ = self->priv->calendar;
#line 134 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp115_, G_TYPE_CHECK_INSTANCE_CAST (_tmp116_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 135 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp117_ = time_content;
#line 135 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp118_ = clock;
#line 135 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp117_, G_TYPE_CHECK_INSTANCE_CAST (_tmp118_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 137 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp119_ = display_options;
#line 137 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp119_) {
#line 1078 "AdjustDateTimeDialog.c"
		GtkBox* _tmp120_;
		GtkRadioButton* _tmp121_;
		GtkBox* _tmp122_;
		GtkRadioButton* _tmp123_;
		GtkBox* _tmp124_;
		GtkCheckButton* _tmp125_;
#line 138 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp120_ = time_content;
#line 138 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp121_ = self->priv->relativity_radio_button;
#line 138 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_box_pack_start (_tmp120_, G_TYPE_CHECK_INSTANCE_CAST (_tmp121_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 139 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp122_ = time_content;
#line 139 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp123_ = self->priv->batch_radio_button;
#line 139 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_box_pack_start (_tmp122_, G_TYPE_CHECK_INSTANCE_CAST (_tmp123_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 140 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp124_ = time_content;
#line 140 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp125_ = self->priv->modify_originals_check_button;
#line 140 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_box_pack_start (_tmp124_, G_TYPE_CHECK_INSTANCE_CAST (_tmp125_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1103 "AdjustDateTimeDialog.c"
	}
#line 143 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	preview = NULL;
#line 1107 "AdjustDateTimeDialog.c"
	{
		GdkPixbuf* _tmp126_ = NULL;
		Dateable* _tmp127_;
		GdkPixbuf* _tmp128_;
		GdkPixbuf* _tmp129_;
#line 147 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp127_ = source;
#line 147 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp128_ = thumbnail_source_get_thumbnail (G_TYPE_CHECK_INSTANCE_CAST (_tmp127_, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), ADJUST_DATE_TIME_DIALOG_CALENDAR_THUMBNAIL_SCALE, &_inner_error_);
#line 147 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp126_ = _tmp128_;
#line 147 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1121 "AdjustDateTimeDialog.c"
			goto __catch25_g_error;
		}
#line 147 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp129_ = _tmp126_;
#line 147 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp126_ = NULL;
#line 147 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (preview);
#line 147 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		preview = _tmp129_;
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (_tmp126_);
#line 1134 "AdjustDateTimeDialog.c"
	}
	goto __finally25;
	__catch25_g_error:
	{
		GError* err = NULL;
		Dateable* _tmp130_;
		gchar* _tmp131_;
		gchar* _tmp132_;
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		err = _inner_error_;
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_inner_error_ = NULL;
#line 149 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp130_ = source;
#line 149 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp131_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp130_, TYPE_DATA_OBJECT, DataObject));
#line 149 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp132_ = _tmp131_;
#line 149 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		g_warning ("AdjustDateTimeDialog.vala:149: Unable to fetch preview for %s", _tmp132_);
#line 149 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_free0 (_tmp132_);
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_error_free0 (err);
#line 1159 "AdjustDateTimeDialog.c"
	}
	__finally25:
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (preview);
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (spin);
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (combo);
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (picker);
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (time_content);
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (clock);
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		g_clear_error (&_inner_error_);
#line 144 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		return NULL;
#line 1182 "AdjustDateTimeDialog.c"
	}
#line 152 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp133_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 152 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp133_);
#line 152 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	image_content = _tmp133_;
#line 153 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp134_ = image_content;
#line 153 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp134_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_START);
#line 154 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp135_ = image_content;
#line 154 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_set_homogeneous (_tmp135_, TRUE);
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp137_ = preview;
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp137_ != NULL) {
#line 1202 "AdjustDateTimeDialog.c"
		GdkPixbuf* _tmp138_;
		GtkImage* _tmp139_;
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp138_ = preview;
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp139_ = (GtkImage*) gtk_image_new_from_pixbuf (_tmp138_);
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		g_object_ref_sink (_tmp139_);
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (_tmp136_);
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp136_ = _tmp139_;
#line 1215 "AdjustDateTimeDialog.c"
	} else {
		GtkImage* _tmp140_;
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp140_ = (GtkImage*) gtk_image_new ();
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		g_object_ref_sink (_tmp140_);
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_object_unref0 (_tmp136_);
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp136_ = _tmp140_;
#line 1226 "AdjustDateTimeDialog.c"
	}
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp141_ = _g_object_ref0 (_tmp136_);
#line 155 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	image = _tmp141_;
#line 156 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp142_ = (GtkLabel*) gtk_label_new (NULL);
#line 156 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp142_);
#line 156 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->original_time_label);
#line 156 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->original_time_label = _tmp142_;
#line 157 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp143_ = image_content;
#line 157 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp144_ = image;
#line 157 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp143_, G_TYPE_CHECK_INSTANCE_CAST (_tmp144_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 158 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp145_ = image_content;
#line 158 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp146_ = self->priv->original_time_label;
#line 158 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp145_, G_TYPE_CHECK_INSTANCE_CAST (_tmp146_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 160 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp147_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
#line 160 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp147_);
#line 160 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	hbox = _tmp147_;
#line 161 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp148_ = hbox;
#line 161 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp148_, gtk_container_get_type (), GtkContainer), (guint) 3);
#line 162 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp149_ = hbox;
#line 162 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp150_ = image_content;
#line 162 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp149_, G_TYPE_CHECK_INSTANCE_CAST (_tmp150_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 163 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp151_ = hbox;
#line 163 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp152_ = time_content;
#line 163 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (_tmp151_, G_TYPE_CHECK_INSTANCE_CAST (_tmp152_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 164 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp153_ = hbox;
#line 164 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp153_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 165 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp154_ = hbox;
#line 165 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp154_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 166 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp155_ = hbox;
#line 166 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_widget_set_hexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp155_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 167 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp156_ = hbox;
#line 167 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_widget_set_vexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp156_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 169 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp157_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 169 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp158_ = hbox;
#line 169 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp157_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (_tmp158_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 171 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp159_ = (GtkLabel*) gtk_label_new ("");
#line 171 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_ref_sink (_tmp159_);
#line 171 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->notification);
#line 171 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->notification = _tmp159_;
#line 172 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp160_ = self->priv->notification;
#line 172 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_label_set_line_wrap (_tmp160_, TRUE);
#line 173 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp161_ = self->priv->notification;
#line 173 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_label_set_justify (_tmp161_, GTK_JUSTIFY_CENTER);
#line 175 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp162_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 175 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp163_ = self->priv->notification;
#line 175 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp162_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (_tmp163_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 177 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp164_ = source;
#line 177 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp165_ = dateable_get_exposure_time (_tmp164_);
#line 177 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->original_time = _tmp165_;
#line 179 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp166_ = self->priv->original_time;
#line 179 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp166_ == ((time_t) 0)) {
#line 1328 "AdjustDateTimeDialog.c"
		time_t _tmp167_;
#line 180 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp167_ = time (NULL);
#line 180 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		self->priv->original_time = _tmp167_;
#line 181 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		self->priv->no_original_time = TRUE;
#line 1336 "AdjustDateTimeDialog.c"
	}
#line 184 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp168_ = self->priv->original_time;
#line 184 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_time_local (_tmp168_, &_tmp169_);
#line 184 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	adjust_date_time_dialog_set_time (self, &_tmp169_);
#line 185 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp170_ = config_facade_get_instance ();
#line 185 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp171_ = _tmp170_;
#line 185 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp172_ = configuration_facade_get_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp171_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 185 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	adjust_date_time_dialog_set_original_time_label (self, _tmp172_);
#line 185 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (_tmp171_);
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (hbox);
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (image);
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (_tmp136_);
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (image_content);
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (preview);
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (spin);
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (combo);
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (picker);
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (time_content);
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (clock);
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	return self;
#line 1376 "AdjustDateTimeDialog.c"
}


AdjustDateTimeDialog* adjust_date_time_dialog_new (Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video) {
#line 37 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	return adjust_date_time_dialog_construct (TYPE_ADJUST_DATE_TIME_DIALOG, source, photo_count, display_options, contains_video, only_video);
#line 1383 "AdjustDateTimeDialog.c"
}


static void adjust_date_time_dialog_set_time (AdjustDateTimeDialog* self, struct tm* time) {
	GtkCalendar* _tmp0_;
	struct tm _tmp1_;
	gint _tmp2_;
	struct tm _tmp3_;
	gint _tmp4_;
	GtkCalendar* _tmp5_;
	struct tm _tmp6_;
	gint _tmp7_;
	GtkCalendar* _tmp8_;
	GtkCalendar* _tmp9_;
	ConfigFacade* _tmp10_;
	ConfigFacade* _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_;
	GtkSpinButton* _tmp28_;
	struct tm _tmp29_;
	gint _tmp30_;
	GtkSpinButton* _tmp31_;
	struct tm _tmp32_;
	gint _tmp33_;
	GtkComboBoxText* _tmp34_;
	gint _tmp35_;
#line 188 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 188 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_return_if_fail (time != NULL);
#line 189 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp0_ = self->priv->calendar;
#line 189 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp1_ = *time;
#line 189 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp2_ = _tmp1_.tm_mon;
#line 189 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp3_ = *time;
#line 189 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp4_ = _tmp3_.tm_year;
#line 189 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_calendar_select_month (_tmp0_, (guint) _tmp2_, (guint) (_tmp4_ + ADJUST_DATE_TIME_DIALOG_YEAR_OFFSET));
#line 190 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp5_ = self->priv->calendar;
#line 190 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp6_ = *time;
#line 190 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp7_ = _tmp6_.tm_mday;
#line 190 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_calendar_select_day (_tmp5_, (guint) _tmp7_);
#line 191 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp8_ = self->priv->calendar;
#line 191 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_notify (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, G_TYPE_OBJECT, GObject), "year");
#line 192 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp9_ = self->priv->calendar;
#line 192 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_notify (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, G_TYPE_OBJECT, GObject), "month");
#line 194 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp10_ = config_facade_get_instance ();
#line 194 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp11_ = _tmp10_;
#line 194 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp12_ = configuration_facade_get_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 194 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp13_ = _tmp12_;
#line 194 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (_tmp11_);
#line 194 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp13_) {
#line 1454 "AdjustDateTimeDialog.c"
		GtkComboBoxText* _tmp14_;
		GtkSpinButton* _tmp15_;
		struct tm _tmp16_;
		gint _tmp17_;
#line 195 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp14_ = self->priv->system;
#line 195 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_combo_box_get_type (), GtkComboBox), (gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR);
#line 196 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp15_ = self->priv->hour;
#line 196 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp16_ = *time;
#line 196 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp17_ = _tmp16_.tm_hour;
#line 196 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_spin_button_set_value (_tmp15_, (gdouble) _tmp17_);
#line 1471 "AdjustDateTimeDialog.c"
	} else {
		gint AMPM_hour = 0;
		struct tm _tmp18_;
		gint _tmp19_;
		gint _tmp20_ = 0;
		gint _tmp21_;
		GtkSpinButton* _tmp23_;
		AdjustDateTimeDialogTimeSystem _tmp24_ = 0;
		struct tm _tmp25_;
		gint _tmp26_;
		GtkComboBoxText* _tmp27_;
#line 198 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp18_ = *time;
#line 198 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp19_ = _tmp18_.tm_hour;
#line 198 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		AMPM_hour = _tmp19_ % 12;
#line 199 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp21_ = AMPM_hour;
#line 199 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (_tmp21_ == 0) {
#line 199 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp20_ = 12;
#line 1495 "AdjustDateTimeDialog.c"
		} else {
			gint _tmp22_;
#line 199 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp22_ = AMPM_hour;
#line 199 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp20_ = _tmp22_;
#line 1502 "AdjustDateTimeDialog.c"
		}
#line 199 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp23_ = self->priv->hour;
#line 199 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_spin_button_set_value (_tmp23_, (gdouble) _tmp20_);
#line 200 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp25_ = *time;
#line 200 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp26_ = _tmp25_.tm_hour;
#line 200 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (_tmp26_ >= 12) {
#line 200 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp24_ = ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM;
#line 1516 "AdjustDateTimeDialog.c"
		} else {
#line 200 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp24_ = ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM;
#line 1520 "AdjustDateTimeDialog.c"
		}
#line 200 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp27_ = self->priv->system;
#line 200 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_combo_box_get_type (), GtkComboBox), (gint) _tmp24_);
#line 1526 "AdjustDateTimeDialog.c"
	}
#line 203 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp28_ = self->priv->minute;
#line 203 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp29_ = *time;
#line 203 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp30_ = _tmp29_.tm_min;
#line 203 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_spin_button_set_value (_tmp28_, (gdouble) _tmp30_);
#line 204 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp31_ = self->priv->second;
#line 204 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp32_ = *time;
#line 204 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp33_ = _tmp32_.tm_sec;
#line 204 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_spin_button_set_value (_tmp31_, (gdouble) _tmp33_);
#line 206 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp34_ = self->priv->system;
#line 206 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp35_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, gtk_combo_box_get_type (), GtkComboBox));
#line 206 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->previous_time_system = (AdjustDateTimeDialogTimeSystem) _tmp35_;
#line 1550 "AdjustDateTimeDialog.c"
}


static void adjust_date_time_dialog_set_original_time_label (AdjustDateTimeDialog* self, gboolean use_24_hr_format) {
	gboolean _tmp0_;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_;
	GtkLabel* _tmp3_;
	time_t _tmp4_;
	struct tm _tmp5_ = {0};
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
#line 209 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 210 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp0_ = self->priv->no_original_time;
#line 210 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp0_) {
#line 211 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		return;
#line 1573 "AdjustDateTimeDialog.c"
	}
#line 214 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp2_ = use_24_hr_format;
#line 214 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp2_) {
#line 214 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp1_ = _ ("%m/%d/%Y, %H:%M:%S");
#line 1581 "AdjustDateTimeDialog.c"
	} else {
#line 215 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp1_ = _ ("%m/%d/%Y, %I:%M:%S %p");
#line 1585 "AdjustDateTimeDialog.c"
	}
#line 213 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp3_ = self->priv->original_time_label;
#line 213 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp4_ = self->priv->original_time;
#line 213 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_time_local (_tmp4_, &_tmp5_);
#line 213 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp6_ = g_time_format (&_tmp5_, _tmp1_);
#line 213 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp7_ = _tmp6_;
#line 213 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp8_ = g_strconcat (_ ("Original: "), _tmp7_, NULL);
#line 213 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp9_ = _tmp8_;
#line 213 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_label_set_text (_tmp3_, _tmp9_);
#line 213 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_free0 (_tmp9_);
#line 213 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_free0 (_tmp7_);
#line 1607 "AdjustDateTimeDialog.c"
}


static time_t adjust_date_time_dialog_get_time (AdjustDateTimeDialog* self) {
	time_t result = 0;
	struct tm time = {0};
	GtkSpinButton* _tmp0_;
	gdouble _tmp1_;
	GtkSpinButton* _tmp2_;
	gdouble _tmp3_;
	gint hour = 0;
	GtkSpinButton* _tmp4_;
	gdouble _tmp5_;
	gint _tmp6_ = 0;
	gboolean _tmp7_ = FALSE;
	gint _tmp8_;
	gint _tmp12_ = 0;
	GtkComboBoxText* _tmp13_;
	gint _tmp14_;
	gint _tmp15_;
	guint year = 0U;
	guint month = 0U;
	guint day = 0U;
	GtkCalendar* _tmp16_;
	guint _tmp17_ = 0U;
	guint _tmp18_ = 0U;
	guint _tmp19_ = 0U;
	time_t _tmp20_;
#line 218 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_return_val_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self), 0);
#line 219 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	memset (&time, 0, sizeof (struct tm));
#line 221 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp0_ = self->priv->second;
#line 221 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp1_ = gtk_spin_button_get_value (_tmp0_);
#line 221 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	time.tm_sec = (gint) _tmp1_;
#line 222 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp2_ = self->priv->minute;
#line 222 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp3_ = gtk_spin_button_get_value (_tmp2_);
#line 222 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	time.tm_min = (gint) _tmp3_;
#line 225 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp4_ = self->priv->hour;
#line 225 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp5_ = gtk_spin_button_get_value (_tmp4_);
#line 225 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	hour = (gint) _tmp5_;
#line 226 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp8_ = hour;
#line 226 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp8_ == 12) {
#line 1662 "AdjustDateTimeDialog.c"
		GtkComboBoxText* _tmp9_;
		gint _tmp10_;
#line 226 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp9_ = self->priv->system;
#line 226 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp10_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_combo_box_get_type (), GtkComboBox));
#line 226 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp7_ = _tmp10_ != ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR);
#line 1671 "AdjustDateTimeDialog.c"
	} else {
#line 226 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp7_ = FALSE;
#line 1675 "AdjustDateTimeDialog.c"
	}
#line 226 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp7_) {
#line 226 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp6_ = 0;
#line 1681 "AdjustDateTimeDialog.c"
	} else {
		gint _tmp11_;
#line 226 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp11_ = hour;
#line 226 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp6_ = _tmp11_;
#line 1688 "AdjustDateTimeDialog.c"
	}
#line 226 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	time.tm_hour = _tmp6_;
#line 227 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp13_ = self->priv->system;
#line 227 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp14_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_combo_box_get_type (), GtkComboBox));
#line 227 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp14_ == ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM)) {
#line 227 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp12_ = 12;
#line 1700 "AdjustDateTimeDialog.c"
	} else {
#line 227 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp12_ = 0;
#line 1704 "AdjustDateTimeDialog.c"
	}
#line 227 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp15_ = time.tm_hour;
#line 227 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	time.tm_hour = _tmp15_ + _tmp12_;
#line 230 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp16_ = self->priv->calendar;
#line 230 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_calendar_get_date (_tmp16_, &_tmp17_, &_tmp18_, &_tmp19_);
#line 230 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	year = _tmp17_;
#line 230 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	month = _tmp18_;
#line 230 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	day = _tmp19_;
#line 231 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	time.tm_year = ((gint) year) - ADJUST_DATE_TIME_DIALOG_YEAR_OFFSET;
#line 232 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	time.tm_mon = (gint) month;
#line 233 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	time.tm_mday = (gint) day;
#line 235 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	time.tm_isdst = -1;
#line 237 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp20_ = mktime (&time);
#line 237 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	result = _tmp20_;
#line 237 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	return result;
#line 1734 "AdjustDateTimeDialog.c"
}


gboolean adjust_date_time_dialog_execute (AdjustDateTimeDialog* self, gint64* time_shift, gboolean* keep_relativity, gboolean* modify_originals) {
	gint64 _vala_time_shift = 0LL;
	gboolean _vala_keep_relativity = FALSE;
	gboolean _vala_modify_originals = FALSE;
	gboolean result = FALSE;
	gboolean response = FALSE;
	gint _tmp0_;
#line 240 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_return_val_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self), FALSE);
#line 242 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 244 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	response = FALSE;
#line 246 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp0_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 246 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_OK)) {
#line 1755 "AdjustDateTimeDialog.c"
		gboolean _tmp1_;
		GtkRadioButton* _tmp5_;
		gboolean _tmp6_;
		GtkRadioButton* _tmp7_;
		gboolean _tmp8_;
		gboolean _tmp9_;
		GtkCheckButton* _tmp13_;
		gboolean _tmp14_;
		GtkCheckButton* _tmp15_;
		gboolean _tmp16_;
		gboolean _tmp17_;
#line 247 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp1_ = self->priv->no_original_time;
#line 247 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (_tmp1_) {
#line 1771 "AdjustDateTimeDialog.c"
			time_t _tmp2_;
#line 248 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp2_ = adjust_date_time_dialog_get_time (self);
#line 248 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_vala_time_shift = (gint64) _tmp2_;
#line 1777 "AdjustDateTimeDialog.c"
		} else {
			time_t _tmp3_;
			time_t _tmp4_;
#line 250 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp3_ = adjust_date_time_dialog_get_time (self);
#line 250 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp4_ = self->priv->original_time;
#line 250 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_vala_time_shift = (gint64) (_tmp3_ - _tmp4_);
#line 1787 "AdjustDateTimeDialog.c"
		}
#line 252 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp5_ = self->priv->relativity_radio_button;
#line 252 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp6_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 252 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_vala_keep_relativity = _tmp6_;
#line 254 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp7_ = self->priv->relativity_radio_button;
#line 254 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp8_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget));
#line 254 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp9_ = _tmp8_;
#line 254 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (_tmp9_) {
#line 1803 "AdjustDateTimeDialog.c"
			ConfigFacade* _tmp10_;
			ConfigFacade* _tmp11_;
			gboolean _tmp12_;
#line 255 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp10_ = config_facade_get_instance ();
#line 255 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp11_ = _tmp10_;
#line 255 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp12_ = _vala_keep_relativity;
#line 255 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			configuration_facade_set_keep_relativity (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp12_);
#line 255 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_g_object_unref0 (_tmp11_);
#line 1817 "AdjustDateTimeDialog.c"
		}
#line 257 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp13_ = self->priv->modify_originals_check_button;
#line 257 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp14_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 257 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_vala_modify_originals = _tmp14_;
#line 259 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp15_ = self->priv->modify_originals_check_button;
#line 259 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp16_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_widget_get_type (), GtkWidget));
#line 259 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp17_ = _tmp16_;
#line 259 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (_tmp17_) {
#line 1833 "AdjustDateTimeDialog.c"
			ConfigFacade* _tmp18_;
			ConfigFacade* _tmp19_;
			gboolean _tmp20_;
#line 260 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp18_ = config_facade_get_instance ();
#line 260 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp19_ = _tmp18_;
#line 260 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp20_ = _vala_modify_originals;
#line 260 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			configuration_facade_set_modify_originals (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp20_);
#line 260 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_g_object_unref0 (_tmp19_);
#line 1847 "AdjustDateTimeDialog.c"
		}
#line 262 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		response = TRUE;
#line 1851 "AdjustDateTimeDialog.c"
	} else {
#line 264 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_vala_time_shift = (gint64) 0;
#line 265 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_vala_keep_relativity = TRUE;
#line 266 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_vala_modify_originals = FALSE;
#line 1859 "AdjustDateTimeDialog.c"
	}
#line 269 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 271 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	result = response;
#line 271 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (time_shift) {
#line 271 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		*time_shift = _vala_time_shift;
#line 1869 "AdjustDateTimeDialog.c"
	}
#line 271 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (keep_relativity) {
#line 271 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		*keep_relativity = _vala_keep_relativity;
#line 1875 "AdjustDateTimeDialog.c"
	}
#line 271 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (modify_originals) {
#line 271 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		*modify_originals = _vala_modify_originals;
#line 1881 "AdjustDateTimeDialog.c"
	}
#line 271 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	return result;
#line 1885 "AdjustDateTimeDialog.c"
}


static gboolean adjust_date_time_dialog_on_spin_button_output (AdjustDateTimeDialog* self, GtkSpinButton* button) {
	gboolean result = FALSE;
	GtkSpinButton* _tmp0_;
	GtkSpinButton* _tmp1_;
	gdouble _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 274 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_return_val_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self), FALSE);
#line 274 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_return_val_if_fail (GTK_IS_SPIN_BUTTON (button), FALSE);
#line 275 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp0_ = button;
#line 275 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp1_ = button;
#line 275 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp2_ = gtk_spin_button_get_value (_tmp1_);
#line 275 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp3_ = g_strdup_printf ("%02d", (gint) _tmp2_);
#line 275 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp4_ = _tmp3_;
#line 275 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	gtk_entry_set_text (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_entry_get_type (), GtkEntry), _tmp4_);
#line 275 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_free0 (_tmp4_);
#line 277 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	adjust_date_time_dialog_on_time_changed (self);
#line 279 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	result = TRUE;
#line 279 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	return result;
#line 1920 "AdjustDateTimeDialog.c"
}


static void adjust_date_time_dialog_on_time_changed (AdjustDateTimeDialog* self) {
	gint64 time_shift = 0LL;
	time_t _tmp0_;
	time_t _tmp1_;
	GtkCalendar* _tmp2_;
	GtkCalendar* _tmp3_;
	GtkComboBoxText* _tmp4_;
	gint _tmp5_;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
	gint64 _tmp8_;
#line 282 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 283 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp0_ = adjust_date_time_dialog_get_time (self);
#line 283 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp1_ = self->priv->original_time;
#line 283 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	time_shift = ((gint64) _tmp0_) - ((gint64) _tmp1_);
#line 284 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp2_ = self->priv->calendar;
#line 284 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_notify (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, G_TYPE_OBJECT, GObject), "year");
#line 285 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp3_ = self->priv->calendar;
#line 285 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_object_notify (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, G_TYPE_OBJECT, GObject), "month");
#line 287 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp4_ = self->priv->system;
#line 287 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp5_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_combo_box_get_type (), GtkComboBox));
#line 287 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->previous_time_system = (AdjustDateTimeDialogTimeSystem) _tmp5_;
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp8_ = time_shift;
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp8_ == ((gint64) 0)) {
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp7_ = TRUE;
#line 1963 "AdjustDateTimeDialog.c"
	} else {
		gboolean _tmp9_;
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp9_ = self->priv->no_original_time;
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp7_ = _tmp9_;
#line 1970 "AdjustDateTimeDialog.c"
	}
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp7_) {
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp6_ = TRUE;
#line 1976 "AdjustDateTimeDialog.c"
	} else {
		gboolean _tmp10_ = FALSE;
		GtkRadioButton* _tmp11_;
		gboolean _tmp12_;
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp11_ = self->priv->batch_radio_button;
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp12_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (_tmp12_) {
#line 1987 "AdjustDateTimeDialog.c"
			GtkRadioButton* _tmp13_;
			gboolean _tmp14_;
			gboolean _tmp15_;
#line 290 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp13_ = self->priv->batch_radio_button;
#line 290 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp14_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_widget_get_type (), GtkWidget));
#line 290 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp15_ = _tmp14_;
#line 290 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp10_ = _tmp15_;
#line 1999 "AdjustDateTimeDialog.c"
		} else {
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp10_ = FALSE;
#line 2003 "AdjustDateTimeDialog.c"
		}
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp6_ = _tmp10_;
#line 2007 "AdjustDateTimeDialog.c"
	}
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp6_) {
#line 2011 "AdjustDateTimeDialog.c"
		GtkLabel* _tmp16_;
#line 291 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp16_ = self->priv->notification;
#line 291 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_widget_get_type (), GtkWidget));
#line 2017 "AdjustDateTimeDialog.c"
	} else {
		gboolean forward = FALSE;
		gint64 _tmp17_;
		gint days = 0;
		gint hours = 0;
		gint minutes = 0;
		gint seconds = 0;
		gint64 _tmp18_;
		gint64 _tmp19_;
		gint64 _tmp20_;
		gint64 _tmp21_;
		gint64 _tmp22_;
		gint64 _tmp23_;
		gint64 _tmp24_;
		gint64 _tmp25_;
		const gchar* _tmp26_ = NULL;
		gboolean _tmp27_;
		gchar* shift_status = NULL;
		gchar* _tmp28_;
		GtkLabel* _tmp29_;
		const gchar* _tmp30_;
		gint _tmp31_;
		gint _tmp32_;
		gint _tmp33_;
		gint _tmp34_;
		gint _tmp35_;
		gint _tmp36_;
		gint _tmp37_;
		gint _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		GtkLabel* _tmp41_;
#line 293 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp17_ = time_shift;
#line 293 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		forward = _tmp17_ > ((gint64) 0);
#line 296 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp18_ = time_shift;
#line 296 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp19_ = llabs (_tmp18_);
#line 296 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		time_shift = _tmp19_;
#line 298 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp20_ = time_shift;
#line 298 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		days = (gint) (_tmp20_ / ADJUST_DATE_TIME_DIALOG_SECONDS_IN_DAY);
#line 299 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp21_ = time_shift;
#line 299 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		time_shift = _tmp21_ % ADJUST_DATE_TIME_DIALOG_SECONDS_IN_DAY;
#line 300 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp22_ = time_shift;
#line 300 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		hours = (gint) (_tmp22_ / ADJUST_DATE_TIME_DIALOG_SECONDS_IN_HOUR);
#line 301 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp23_ = time_shift;
#line 301 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		time_shift = _tmp23_ % ADJUST_DATE_TIME_DIALOG_SECONDS_IN_HOUR;
#line 302 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp24_ = time_shift;
#line 302 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		minutes = (gint) (_tmp24_ / ADJUST_DATE_TIME_DIALOG_SECONDS_IN_MINUTE);
#line 303 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp25_ = time_shift;
#line 303 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		seconds = (gint) (_tmp25_ % ADJUST_DATE_TIME_DIALOG_SECONDS_IN_MINUTE);
#line 305 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp27_ = forward;
#line 305 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (_tmp27_) {
#line 306 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp26_ = _ ("Exposure time will be shifted forward by\n" \
"%d %s, %d %s, %d %s, and %d %s.");
#line 2090 "AdjustDateTimeDialog.c"
		} else {
#line 307 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp26_ = _ ("Exposure time will be shifted backward by\n" \
"%d %s, %d %s, %d %s, and %d %s.");
#line 2094 "AdjustDateTimeDialog.c"
		}
#line 305 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp28_ = g_strdup (_tmp26_);
#line 305 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		shift_status = _tmp28_;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp29_ = self->priv->notification;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp30_ = shift_status;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp31_ = days;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp32_ = days;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp33_ = hours;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp34_ = hours;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp35_ = minutes;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp36_ = minutes;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp37_ = seconds;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp38_ = seconds;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp39_ = g_strdup_printf (_tmp30_, _tmp31_, ngettext ("day", "days", (gulong) _tmp32_), _tmp33_, ngettext ("hour", "hours", (gulong) _tmp34_), _tmp35_, ngettext ("minute", "minutes", (gulong) _tmp36_), _tmp37_, ngettext ("second", "seconds", (gulong) _tmp38_));
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp40_ = _tmp39_;
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_label_set_text (_tmp29_, _tmp40_);
#line 309 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_free0 (_tmp40_);
#line 314 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp41_ = self->priv->notification;
#line 314 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_widget_show (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, gtk_widget_get_type (), GtkWidget));
#line 289 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_g_free0 (shift_status);
#line 2134 "AdjustDateTimeDialog.c"
	}
}


static void adjust_date_time_dialog_on_time_system_changed (AdjustDateTimeDialog* self) {
	AdjustDateTimeDialogTimeSystem _tmp0_;
	GtkComboBoxText* _tmp1_;
	gint _tmp2_;
	ConfigFacade* _tmp3_;
	ConfigFacade* _tmp4_;
	GtkComboBoxText* _tmp5_;
	gint _tmp6_;
	GtkComboBoxText* _tmp7_;
	gint _tmp8_;
#line 318 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 319 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp0_ = self->priv->previous_time_system;
#line 319 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp1_ = self->priv->system;
#line 319 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 319 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp0_ == _tmp2_) {
#line 320 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		return;
#line 2161 "AdjustDateTimeDialog.c"
	}
#line 322 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp3_ = config_facade_get_instance ();
#line 322 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp4_ = _tmp3_;
#line 322 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp5_ = self->priv->system;
#line 322 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp6_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_combo_box_get_type (), GtkComboBox));
#line 322 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	configuration_facade_set_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp6_ == ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR));
#line 322 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (_tmp4_);
#line 324 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp7_ = self->priv->system;
#line 324 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_tmp8_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_combo_box_get_type (), GtkComboBox));
#line 324 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	if (_tmp8_ == ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR)) {
#line 2181 "AdjustDateTimeDialog.c"
		gint _tmp9_ = 0;
		GtkSpinButton* _tmp10_;
		gdouble _tmp11_;
		gint time = 0;
		gint _tmp14_ = 0;
		AdjustDateTimeDialogTimeSystem _tmp15_;
		gint _tmp16_;
		GtkSpinButton* _tmp17_;
		GtkSpinButton* _tmp18_;
		gint _tmp19_;
#line 325 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp10_ = self->priv->hour;
#line 325 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp11_ = gtk_spin_button_get_value (_tmp10_);
#line 325 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (_tmp11_ == 12.0) {
#line 325 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp9_ = 0;
#line 2200 "AdjustDateTimeDialog.c"
		} else {
			GtkSpinButton* _tmp12_;
			gdouble _tmp13_;
#line 325 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp12_ = self->priv->hour;
#line 325 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp13_ = gtk_spin_button_get_value (_tmp12_);
#line 325 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp9_ = (gint) _tmp13_;
#line 2210 "AdjustDateTimeDialog.c"
		}
#line 325 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		time = _tmp9_;
#line 326 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp15_ = self->priv->previous_time_system;
#line 326 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (_tmp15_ == ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM) {
#line 326 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp14_ = 12;
#line 2220 "AdjustDateTimeDialog.c"
		} else {
#line 326 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp14_ = 0;
#line 2224 "AdjustDateTimeDialog.c"
		}
#line 326 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp16_ = time;
#line 326 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		time = _tmp16_ + _tmp14_;
#line 328 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp17_ = self->priv->hour;
#line 328 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_spin_button_set_range (_tmp17_, (gdouble) 0, (gdouble) 23);
#line 329 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		adjust_date_time_dialog_set_original_time_label (self, TRUE);
#line 331 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp18_ = self->priv->hour;
#line 331 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp19_ = time;
#line 331 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_spin_button_set_value (_tmp18_, (gdouble) _tmp19_);
#line 2242 "AdjustDateTimeDialog.c"
	} else {
		gint AMPM_hour = 0;
		GtkSpinButton* _tmp20_;
		gdouble _tmp21_;
		GtkSpinButton* _tmp22_;
		gint _tmp23_ = 0;
		gint _tmp24_;
		GtkSpinButton* _tmp26_;
#line 333 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp20_ = self->priv->hour;
#line 333 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp21_ = gtk_spin_button_get_value (_tmp20_);
#line 333 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		AMPM_hour = ((gint) _tmp21_) % 12;
#line 335 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp22_ = self->priv->hour;
#line 335 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_spin_button_set_range (_tmp22_, (gdouble) 1, (gdouble) 12);
#line 336 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		adjust_date_time_dialog_set_original_time_label (self, FALSE);
#line 338 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp24_ = AMPM_hour;
#line 338 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		if (_tmp24_ == 0) {
#line 338 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp23_ = 12;
#line 2269 "AdjustDateTimeDialog.c"
		} else {
			gint _tmp25_;
#line 338 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp25_ = AMPM_hour;
#line 338 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
			_tmp23_ = _tmp25_;
#line 2276 "AdjustDateTimeDialog.c"
		}
#line 338 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		_tmp26_ = self->priv->hour;
#line 338 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
		gtk_spin_button_set_value (_tmp26_, (gdouble) _tmp23_);
#line 2282 "AdjustDateTimeDialog.c"
	}
#line 341 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	adjust_date_time_dialog_on_time_changed (self);
#line 2286 "AdjustDateTimeDialog.c"
}


static void adjust_date_time_dialog_class_init (AdjustDateTimeDialogClass * klass) {
#line 8 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	adjust_date_time_dialog_parent_class = g_type_class_peek_parent (klass);
#line 8 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	g_type_class_add_private (klass, sizeof (AdjustDateTimeDialogPrivate));
#line 8 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	G_OBJECT_CLASS (klass)->finalize = adjust_date_time_dialog_finalize;
#line 2297 "AdjustDateTimeDialog.c"
}


static void adjust_date_time_dialog_instance_init (AdjustDateTimeDialog * self) {
#line 8 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv = ADJUST_DATE_TIME_DIALOG_GET_PRIVATE (self);
#line 13 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self->priv->no_original_time = FALSE;
#line 2306 "AdjustDateTimeDialog.c"
}


static void adjust_date_time_dialog_finalize (GObject * obj) {
	AdjustDateTimeDialog * self;
#line 8 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialog);
#line 18 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->original_time_label);
#line 19 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->calendar);
#line 20 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->hour);
#line 21 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->minute);
#line 22 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->second);
#line 23 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->system);
#line 24 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->relativity_radio_button);
#line 25 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->batch_radio_button);
#line 26 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->modify_originals_check_button);
#line 27 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	_g_object_unref0 (self->priv->notification);
#line 8 "/home/jens/Source/shotwell/src/dialogs/AdjustDateTimeDialog.vala"
	G_OBJECT_CLASS (adjust_date_time_dialog_parent_class)->finalize (obj);
#line 2336 "AdjustDateTimeDialog.c"
}


GType adjust_date_time_dialog_get_type (void) {
	static volatile gsize adjust_date_time_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&adjust_date_time_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AdjustDateTimeDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) adjust_date_time_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AdjustDateTimeDialog), 0, (GInstanceInitFunc) adjust_date_time_dialog_instance_init, NULL };
		GType adjust_date_time_dialog_type_id;
		adjust_date_time_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "AdjustDateTimeDialog", &g_define_type_info, 0);
		g_once_init_leave (&adjust_date_time_dialog_type_id__volatile, adjust_date_time_dialog_type_id);
	}
	return adjust_date_time_dialog_type_id__volatile;
}



